@@ -79,11 +79,11 @@ def _deduce_PDB_atom_name(name, resname, element=None):
         and (element.strip().capitalize() in _position_12_elements)
         and (name[0:2].upper() == element[0:2].upper())
     ):
-        return "{:<4}".format(name)
+        return f"{name:<4}"
     if len(name) >= 4:
         return name[:4]
     elif len(name) == 1:
-        return " {}  ".format(name)
+        return f" {name}  "
     elif (
         resname == name
         or name[:2] in _ions_metals
@@ -92,8 +92,8 @@ def _deduce_PDB_atom_name(name, resname, element=None):
         or (resname in _special_cl and name[:2] == "CL")
         or _Pair(resname, name) in _include_pairs
     ) and _Pair(resname, name) not in _exclude_pairs:
-        return "{:<4}".format(name)
-    return " {:<3}".format(name)
+        return f"{name:<4}"
+    return f" {name:<3}"
 
 
 def _getPDBElement(name, element, lowersecond=True):
@@ -239,11 +239,11 @@ def PDBwrite(mol, filename, frames=None, writebonds=True, mode="pdb"):
                     mol.chain[i],
                     mol.resid[i],
                     mol.insertion[i],
-                    "{:8.3f}".format(coords[i, 0, f])[:8],
-                    "{:8.3f}".format(coords[i, 1, f])[:8],
-                    "{:8.3f}".format(coords[i, 2, f])[:8],
-                    "{:6.2f}".format(mol.occupancy[i])[:6],
-                    "{:6.2f}".format(mol.beta[i])[:6],
+                    f"{coords[i, 0, f]:8.3f}"[:8],
+                    f"{coords[i, 1, f]:8.3f}"[:8],
+                    f"{coords[i, 2, f]:8.3f}"[:8],
+                    f"{mol.occupancy[i]:6.2f}"[:6],
+                    f"{mol.beta[i]:6.2f}"[:6],
                     prelast,
                     last,
                 )
@@ -263,7 +263,7 @@ def PDBwrite(mol, filename, frames=None, writebonds=True, mode="pdb"):
                 for ni in range(0, len(neighbours), 4):
                     subneighs = neighbours[ni : min(ni + 4, len(neighbours))]
                     neighstring = "".join("%5d" % sn for sn in subneighs)
-                    fh.write("CONECT{:5d}{}\n".format(atom, neighstring))
+                    fh.write(f"CONECT{atom:5d}{neighstring}\n")
 
         fh.write("ENDMDL\n")
     fh.write("END\n")
@@ -503,7 +503,7 @@ def XSCwrite(mol, filename, frames=None):
 
 def MOL2write(mol, filename, explicitbonds=None):
     uqresname = np.unique(mol.resname)
-    if len(uqresname) == 1:
+    if len(uqresname) == 1 and uqresname[0] != "":
         molname = uqresname[0]
     elif len(uqresname[0]) == 0:
         molname = "MOL"
@@ -550,12 +550,32 @@ def MOL2write(mol, filename, explicitbonds=None):
         DSPMOD, TYPECOL, CAP, BACKBONE, DICT, ESSENTIAL, WATER and
         DIRECT.
         """
+        # Guarantee unique residues
+        resnames = []
+        for i in range(mol.numAtoms):
+            resn = mol.resname[i] if mol.resname[i] != "" else "MOL"
+            resnames.append(f"{resn}{mol.resid[i]:<d}{mol.insertion[i]}{mol.chain[i]}")
+
+        # Guarantee unique atom names for each unique residue
+        seen_names = {}
+        atomnames = []
+        for i in range(mol.numAtoms):
+            if resnames[i] not in seen_names:
+                seen_names[resnames[i]] = {}
+            name = mol.name[i]
+            if name not in seen_names[resnames[i]]:
+                seen_names[resnames[i]][name] = 0
+                atomnames.append(name)
+            else:
+                seen_names[resnames[i]][name] += 1
+                atomnames.append(f"{name}{seen_names[resnames[i]][name]}")
+
         f.write("@<TRIPOS>ATOM\n")
         for i in range(mol.coords.shape[0]):
             f.write(
                 "{:7d} {:8s} {:9.4f} {:9.4f} {:9.4f} {:8s} ".format(
                     i + 1,
-                    mol.name[i],
+                    atomnames[i],
                     mol.coords[i, 0, mol.frame],
                     mol.coords[i, 1, mol.frame],
                     mol.coords[i, 2, mol.frame],
@@ -563,12 +583,18 @@ def MOL2write(mol, filename, explicitbonds=None):
                 )
             )
             if isinstance(mol.resid[i], numbers.Integral):
-                f.write(f"{mol.resid[i]} ")
-                if mol.resname[i] != "":
-                    f.write(f"{mol.resname[i]}{mol.resid[i]:<d} ")
-                    if isinstance(mol.charge[i], numbers.Real):
-                        f.write("{:12.4f}".format(mol.charge[i]))
+                f.write(f"{mol.resid[i]} {resnames[i]} ")
+                if isinstance(mol.charge[i], numbers.Real):
+                    f.write(f"{mol.charge[i]:12.4f}")
             f.write("\n")
+
+        # # Disabled because RDKit has issues with this section
+        # if np.any(mol.formalcharge != 0):
+        #     f.write("@<TRIPOS>UNITY_ATOM_ATTR\n")
+        #     idx = np.where(mol.formalcharge != 0)[0]
+        #     for i in idx:
+        #         f.write(f"{i+1} 1\ncharge {mol.formalcharge[i]}\n")
+
         f.write("@<TRIPOS>BOND\n")
         for i in range(unique_bonds.shape[0]):
             bt = "un"
@@ -585,7 +611,7 @@ def MOL2write(mol, filename, explicitbonds=None):
                 ), f"There should only exist one bond type for atoms {unique_bonds[i, 0]} {unique_bonds[i, 1]}"
                 bt = tmp[0]
             f.write(
-                "{:6d} {:4d} {:4d} {}\n".format(
+                "{:6d} {:5d} {:5d} {:>4s}\n".format(
                     i + 1, unique_bonds[i, 0] + 1, unique_bonds[i, 1] + 1, bt
                 )
             )
@@ -595,7 +621,6 @@ def SDFwrite(mol, filename):
     import datetime
 
     mol2bonds = {"1": 1, "2": 2, "3": 3, "ar": 4, "4": 4}
-    chargemap = {-3: 7, -2: 6, -1: 5, 0: 0, 1: 3, 2: 2, 3: 1}
     with open(filename, "w", encoding="ascii") as fh:
         fh.write(f"{mol.viewname}\n")
         currtime = datetime.datetime.now().strftime("%m%d%y%H%M")
@@ -612,10 +637,8 @@ def SDFwrite(mol, filename):
             if element == "":
                 element = mol.name[i]
 
-            charge = 0
-            if mol.charge[i] != 0 and mol.charge[i] in chargemap:
-                charge = chargemap[mol.charge[i]]
-                charges.append([i + 1, int(mol.charge[i])])
+            if mol.formalcharge[i] != 0:
+                charges.append([i + 1, int(mol.formalcharge[i])])
 
             fh.write(
                 f"{coor[i, 0]:>10.4f}{coor[i, 1]:>10.4f}{coor[i, 2]:>10.4f} {element:<2}  0  0  0  0  0  0  0  0  0  0  0  0\n"
